@@ -1,5 +1,8 @@
 {-# LANGUAGE BangPatterns, TypeSynonymInstances, FlexibleInstances #-}
 {-# LANGUAGE CPP #-}
+{-# OPTIONS_GHC -O2 #-}
+{- This module does a lot of calculation that can be expensive, so optimise
+ - it well -}
 
 -- | 
 -- Copyright: 2015 Joey Hess <id@joeyh.name>
